# 安装驱动

## Oracle

1. Visit [Oracle Instant Client](https://www.oracle.com/database/technologies/instant-client/downloads.html) to choose the corresponding platform.
   - [Instant Client for Linux x86-64](https://www.oracle.com/database/technologies/instant-client/linux-x86-64-downloads.html)
   - [Instant Client for Linux ARM (aarch64)](https://www.oracle.com/database/technologies/instant-client/linux-arm-aarch64-downloads.html)
   - [Instant Client for macOS (Intel x86)](https://www.oracle.com/database/technologies/instant-client/macos-intel-x86-downloads.html)
   - [Instant Client for Microsoft Windows (x64) 64-bit](https://www.oracle.com/database/technologies/instant-client/winx64-64-downloads.html)

2. Choose the corresponding version, such as `Version 19.10.0.0.0`.

3. Download the `Basic Package (ZIP)` package and upload it to the server, and run the following command to decompress
   it:

   ```bash
   # This package applies to the arm64 platform.
   unzip instantclient-basic-linux.arm64-19.10.0.0.0dbru.zip
   ```

   After the package is decompressed, the directory like `instantclient_19_10` will be obtained.

4. Configure environment variables.

   ```bash
   # Linux:
   export LD_LIBRARY_PATH=<target directory>/instantclient_19_10:$LD_LIBRARY_PATH
   # Mac:
   export DYLD_LIBRARY_PATH=<target directory>/instantclient_19_10:$DYLD_LIBRARY_PATH
   ```

<br/>

## DB2

1. Visit [DB2 ODBC CLI](http://public.dhe.ibm.com/ibmdl/export/pub/software/data/db2/drivers/odbc_cli/)

2. Choose the platform version. Download package and upload it to the server, and run the following command to decompress it:

   ```bash
   tar -zxvf linuxx64_odbc_cli.tar.gz -C /db2client
   ```

3. Configure environment variables.

   ```bash
   export DB2HOME=/db2client/clidriver
   export CGO_CFLAGS=-I$DB2HOME/include
   export CGO_LDFLAGS=-L$DB2HOME/lib
   export PATH=$DB2HOME/bin:$PATH
   # Linux:
   export LD_LIBRARY_PATH=$DB2HOME/lib:$LD_LIBRARY_PATH
   # Mac:
   export DYLD_LIBRARY_PATH=$DB2HOME/lib:$DYLD_LIBRARY_PATH
   ```

4. Test

    ```bash
    db2cli --version
    ```

   > If the DB2 ODBC CLI driver is not installed, the following error will occur.
   >
   > ```bash
   > mtk: error while loading shared libraries: libdb2.so.1: cannot open shared object file: No such file or directory
   > mtk: error while loading shared libraries: libdb2.so.1: cannot open shared object file: No such file or directory
   > ```

## MySQL

No client needs to be installed.

## openGauss

No client needs to be installed.

## informix

See [DB2](#db2)

## 安装mtkd

```bash
mkdir /opt/mtkd/
cp mtkd /opt/mtkd/mtkd
chmod +x /opt/mtkd/mtkd
```

## 申请授权

```bash
mtkd license gen
# 复制邮箱授权信息到 /opt/mtkd/license.json
```

## start mtkd

### 前台启动

```bash
./mtkd
```

访问8080端口

### 后台启动

```bash
nohup mtkd &
```

访问8080端口

### 服务方式启动

1. vi /etc/systemd/system/mtkd.service

    ```bash
    # -*- mode: conf -*-

    [Unit]
    Description=mtkd
    After=network.target

    [Service]
    # 设置oracle/db2的lib目录
    WorkingDirectory=/opt/mtkd
    Environment="LD_LIBRARY_PATH="
    ExecStart=/opt/mtkd/mtkd --httpAddr=:8080 --logDir=/opt/mtkd/logs --dbDir=/opt/mtkd/
    Restart=on-failure

    [Install]
    WantedBy=multi-user.target
    ```

2. 启动服务

    ```bash
    systemctl status mtkd
    systemctl enable mtkd
    ```

3. 访问8080端口
